/*
 * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * UNICODE LICENSE V3
 *
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright © 1991-2025 Unicode, Inc.
 *
 * NOTICE TO USER: Carefully read the following legal agreement. BY
 * DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING DATA FILES, AND/OR
 * SOFTWARE, YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
 * TERMS AND CONDITIONS OF THIS AGREEMENT. IF YOU DO NOT AGREE, DO NOT
 * DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE THE DATA FILES OR SOFTWARE.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of data files and any associated documentation (the "Data Files") or
 * software and any associated documentation (the "Software") to deal in the
 * Data Files or Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, and/or sell
 * copies of the Data Files or Software, and to permit persons to whom the
 * Data Files or Software are furnished to do so, provided that either (a)
 * this copyright and permission notice appear with all copies of the Data
 * Files or Software, or (b) this copyright and permission notice appear in
 * associated Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
 * KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
 * THIRD PARTY RIGHTS.
 *
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS NOTICE
 * BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL DAMAGES,
 * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
 * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THE DATA
 * FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder shall
 * not be used in advertising or otherwise to promote the sale, use or other
 * dealings in these Data Files or Software without prior written
 * authorization of the copyright holder.
 *
 * SPDX-License-Identifier: Unicode-3.0
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.TimeZoneNamesBundle;

public class TimeZoneNames_br extends TimeZoneNamesBundle {
    @Override
    protected final Object[][] getContents() {
        final String[] GMT = new String[] {
               "amzer keitat Greenwich (AKG)",
               "GMT",
               "",
               "GMT",
               "",
               "GMT",
            };
        final String[] Apia = new String[] {
               "eur cʼhoañv Samoa",
               "",
               "eur hañv Samoa",
               "",
               "eur Samoa",
               "",
            };
        final String[] Cook = new String[] {
               "eur cʼhoañv Inizi Cook",
               "",
               "eur hañv Inizi Cook",
               "",
               "eur Inizi Cook",
               "",
            };
        final String[] Cuba = new String[] {
               "eur cʼhoañv Kuba",
               "CST",
               "eur hañv Kuba",
               "CDT",
               "eur Kuba",
               "CT",
            };
        final String[] Fiji = new String[] {
               "eur cʼhoañv Fidji",
               "",
               "eur hañv Fidji",
               "",
               "eur Fidji",
               "",
            };
        final String[] Gulf = new String[] {
               "eur cʼhoañv ar Pleg-mor Arab-ha-Pers",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Hovd = new String[] {
               "eur cʼhoañv Khovd",
               "",
               "eur hañv Khovd",
               "",
               "eur Khovd",
               "",
            };
        final String[] Iran = new String[] {
               "eur cʼhoañv Iran",
               "",
               "eur hañv Iran",
               "",
               "eur Iran",
               "",
            };
        final String[] Niue = new String[] {
               "eur Niue",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Omsk = new String[] {
               "eur cʼhoañv Omsk",
               "",
               "eur hañv Omsk",
               "",
               "eur Omsk",
               "",
            };
        final String[] Peru = new String[] {
               "eur cʼhoañv Perou",
               "",
               "eur hañv Perou",
               "",
               "eur Perou",
               "",
            };
        final String[] Truk = new String[] {
               "eur Chuuk",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Wake = new String[] {
               "eur Enez Wake",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Chile = new String[] {
               "eur cʼhoañv Chile",
               "",
               "eur hañv Chile",
               "",
               "eur Chile",
               "",
            };
        final String[] China = new String[] {
               "eur cʼhoañv Sina",
               "CST",
               "eur hañv Sina",
               "CDT",
               "eur Sina",
               "CT",
            };
        final String[] Cocos = new String[] {
               "eur Inizi Kokoz",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Davis = new String[] {
               "eur Davis",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] India = new String[] {
               "eur cʼhoañv India",
               "IST",
               "",
               "IST",
               "",
               "IST",
            };
        final String[] Japan = new String[] {
               "eur cʼhoañv Japan",
               "JST",
               "eur hañv Japan",
               "JDT",
               "eur Japan",
               "JT",
            };
        final String[] Korea = new String[] {
               "eur cʼhoañv Korea",
               "KST",
               "eur hañv Korea",
               "KST",
               "eur Korea",
               "KST",
            };
        final String[] Nauru = new String[] {
               "eur Nauru",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Nepal = new String[] {
               "eur Nepal",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Palau = new String[] {
               "eur Palau",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Samoa = new String[] {
               "eur cʼhoañv Samoa Amerikan",
               "SST",
               "eur hañv Samoa Amerikan",
               "SST",
               "eur Samoa Amerikan",
               "SST",
            };
        final String[] Syowa = new String[] {
               "eur Syowa",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Tonga = new String[] {
               "eur cʼhoañv Tonga",
               "",
               "eur hañv Tonga",
               "",
               "eur Tonga",
               "",
            };
        final String[] Yukon = new String[] {
               "eur Yukon",
               "MST",
               "",
               "MST",
               "",
               "MST",
            };
        final String[] Alaska = new String[] {
               "eur cʼhoañv Alaska",
               "AKST",
               "eur hañv Alaska",
               "AKDT",
               "eur Alaska",
               "AKT",
            };
        final String[] Amazon = new String[] {
               "eur cʼhoañv an Amazon",
               "",
               "eur hañv an Amazon",
               "",
               "eur an Amazon",
               "",
            };
        final String[] Azores = new String[] {
               "eur cʼhoañv an Azorez",
               "",
               "eur hañv an Azorez",
               "",
               "eur an Azorez",
               "",
            };
        final String[] Bhutan = new String[] {
               "eur Bhoutan",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Brunei = new String[] {
               "eur Brunei",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Easter = new String[] {
               "eur cʼhoañv Enez Pask",
               "",
               "eur hañv Enez Pask",
               "",
               "eur Enez Pask",
               "",
            };
        final String[] Guyana = new String[] {
               "eur Guyana",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Hawaii = new String[] {
               "eur cʼhoañv Hawaii hag an Aleouted",
               "HST",
               "",
               "HST",
               "",
               "HST",
            };
        final String[] Israel = new String[] {
               "eur cʼhoañv Israel",
               "IST",
               "eur hañv Israel",
               "IDT",
               "eur Israel",
               "IT",
            };
        final String[] Kosrae = new String[] {
               "eur Kosrae",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Mawson = new String[] {
               "eur Mawson",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Moscow = new String[] {
               "eur cʼhoañv Moskov",
               "MSK",
               "eur hañv Moskov",
               "MSK",
               "eur Moskov",
               "MSK",
            };
        final String[] Ponape = new String[] {
               "eur Pohnpei",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Tahiti = new String[] {
               "eur Tahiti",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Taipei = new String[] {
               "eur cʼhoañv Taiwan",
               "CST",
               "eur hañv Taiwan",
               "CDT",
               "eur Taiwan",
               "CT",
            };
        final String[] Tuvalu = new String[] {
               "eur Tuvalu",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Vostok = new String[] {
               "eur Vostok",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Wallis = new String[] {
               "eur Wallis-ha-Futuna",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Arabian = new String[] {
               "eur cʼhoañv Arabia",
               "",
               "eur hañv Arabia",
               "",
               "eur Arabia",
               "",
            };
        final String[] Armenia = new String[] {
               "eur cʼhoañv Armenia",
               "",
               "eur hañv Armenia",
               "",
               "eur Armenia",
               "",
            };
        final String[] Bolivia = new String[] {
               "eur Bolivia",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Chatham = new String[] {
               "eur cʼhoañv Chatham",
               "",
               "eur hañv Chatham",
               "",
               "eur Chatham",
               "",
            };
        final String[] ETC_UTC = new String[] {
               "amzer hollvedel kenurzhiet",
               "UTC",
               "",
               "",
               "",
               "",
            };
        final String[] Ecuador = new String[] {
               "eur Ecuador",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Gambier = new String[] {
               "eur Inizi Gambier",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Georgia = new String[] {
               "eur cʼhoañv Jorjia",
               "",
               "eur hañv Jorjia",
               "",
               "eur Jorjia",
               "",
            };
        final String[] Irkutsk = new String[] {
               "eur cʼhoañv Irkutsk",
               "",
               "eur hañv Irkutsk",
               "",
               "eur Irkutsk",
               "",
            };
        final String[] Magadan = new String[] {
               "eur cʼhoañv Magadan",
               "",
               "eur hañv Magadan",
               "",
               "eur Magadan",
               "",
            };
        final String[] Myanmar = new String[] {
               "eur Myanmar",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Norfolk = new String[] {
               "eur cʼhoañv Enez Norfolk",
               "",
               "eur hañv Enez Norfolk",
               "",
               "eur Enez Norfolk",
               "",
            };
        final String[] Noronha = new String[] {
               "eur cʼhoañv Fernando de Noronha",
               "",
               "eur hañv Fernando de Noronha",
               "",
               "eur Fernando de Noronha",
               "",
            };
        final String[] Reunion = new String[] {
               "eur ar Reünion",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Rothera = new String[] {
               "eur Rothera",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Solomon = new String[] {
               "eur Inizi Salomon",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Tokelau = new String[] {
               "eur Tokelau",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Uruguay = new String[] {
               "eur cʼhoañv Uruguay",
               "",
               "eur hañv Uruguay",
               "",
               "eur Uruguay",
               "",
            };
        final String[] Vanuatu = new String[] {
               "eur cʼhoañv Vanuatu",
               "",
               "eur hañv Vanuatu",
               "",
               "eur Vanuatu",
               "",
            };
        final String[] Yakutsk = new String[] {
               "eur cʼhoañv Yakutsk",
               "",
               "eur hañv Yakutsk",
               "",
               "eur Yakutsk",
               "",
            };
        final String[] Atlantic = new String[] {
               "eur cʼhoañv an Atlantel",
               "AST",
               "eur hañv an Atlantel",
               "AST",
               "eur an Atlantel",
               "AST",
            };
        final String[] Brasilia = new String[] {
               "eur cʼhoañv Brasília",
               "",
               "eur hañv Brasília",
               "",
               "eur Brasília",
               "",
            };
        final String[] Chamorro = new String[] {
               "eur Chamorro",
               "ChST",
               "",
               "ChST",
               "",
               "ChST",
            };
        final String[] Colombia = new String[] {
               "eur cʼhoañv Kolombia",
               "",
               "eur hañv Kolombia",
               "",
               "eur Kolombia",
               "",
            };
        final String[] Falkland = new String[] {
               "eur cʼhoañv Inizi Falkland",
               "",
               "eur hañv Inizi Falkland",
               "",
               "eur Inizi Falkland",
               "",
            };
        final String[] Malaysia = new String[] {
               "eur Malaysia",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Maldives = new String[] {
               "eur ar Maldivez",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Mongolia = new String[] {
               "eur cʼhoañv Ulaanbaatar",
               "",
               "eur hañv Ulaanbaatar",
               "",
               "eur Ulaanbaatar",
               "",
            };
        final String[] Pakistan = new String[] {
               "eur cʼhoañv Pakistan",
               "PKT",
               "eur hañv Pakistan",
               "PKST",
               "eur Pakistan",
               "PKT",
            };
        final String[] Paraguay = new String[] {
               "eur cʼhoañv Paraguay",
               "",
               "eur hañv Paraguay",
               "",
               "eur Paraguay",
               "",
            };
        final String[] Pitcairn = new String[] {
               "eur Pitcairn",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Suriname = new String[] {
               "eur Surinam",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Argentina = new String[] {
               "eur cʼhoañv Arcʼhantina",
               "",
               "eur hañv Arcʼhantina",
               "",
               "eur Arcʼhantina",
               "",
            };
        final String[] Christmas = new String[] {
               "eur Enez Christmas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Galapagos = new String[] {
               "eur Inizi Galápagos",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Hong_Kong = new String[] {
               "eur cʼhoañv Hong Kong",
               "HKT",
               "eur hañv Hong Kong",
               "HKST",
               "eur Hong Kong",
               "HKT",
            };
        final String[] Indochina = new String[] {
               "eur Indez-Sina",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Kyrgystan = new String[] {
               "eur Kyrgyzstan",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Lord_Howe = new String[] {
               "eur cʼhoañv Lord Howe",
               "",
               "eur hañv Lord Howe",
               "",
               "eur Lord Howe",
               "",
            };
        final String[] Marquesas = new String[] {
               "eur Inizi Markiz",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Mauritius = new String[] {
               "eur cʼhoañv Moris",
               "",
               "eur hañv Moris",
               "",
               "eur Moris",
               "",
            };
        final String[] Singapore = new String[] {
               "eur cʼhoañv Singapour",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Venezuela = new String[] {
               "eur Venezuela",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Azerbaijan = new String[] {
               "eur cʼhoañv Azerbaidjan",
               "",
               "eur hañv Azerbaidjan",
               "",
               "eur Azerbaidjan",
               "",
            };
        final String[] Bangladesh = new String[] {
               "eur cʼhoañv Bangladesh",
               "",
               "eur hañv Bangladesh",
               "",
               "eur Bangladesh",
               "",
            };
        final String[] Cape_Verde = new String[] {
               "eur cʼhoañv ar Cʼhab-Glas",
               "",
               "eur hañv ar Cʼhab-Glas",
               "",
               "eur ar Cʼhab-Glas",
               "",
            };
        final String[] East_Timor = new String[] {
               "eur Timor ar Reter",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Kazakhstan = new String[] {
               "eur Kazakstan",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Seychelles = new String[] {
               "eur Sechelez",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Tajikistan = new String[] {
               "eur Tadjikistan",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Uzbekistan = new String[] {
               "eur cʼhoañv Ouzbekistan",
               "",
               "eur hañv Ouzbekistan",
               "",
               "eur Ouzbekistan",
               "",
            };
        final String[] Afghanistan = new String[] {
               "eur Afghanistan",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Krasnoyarsk = new String[] {
               "eur cʼhoañv Krasnoyarsk",
               "",
               "eur hañv Krasnoyarsk",
               "",
               "eur Krasnoyarsk",
               "",
            };
        final String[] New_Zealand = new String[] {
               "eur cʼhoañv Zeland-Nevez",
               "NZST",
               "eur hañv Zeland-Nevez",
               "NZDT",
               "eur Zeland-Nevez",
               "NZT",
            };
        final String[] Philippines = new String[] {
               "eur cʼhoañv ar Filipinez",
               "PST",
               "eur hañv ar Filipinez",
               "PDT",
               "eur ar Filipinez",
               "PT",
            };
        final String[] Vladivostok = new String[] {
               "eur cʼhoañv Vladivostok",
               "",
               "eur hañv Vladivostok",
               "",
               "eur Vladivostok",
               "",
            };
        final String[] Indian_Ocean = new String[] {
               "eur Meurvor Indez",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Line_Islands = new String[] {
               "eur Line Islands",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Newfoundland = new String[] {
               "eur cʼhoañv Newfoundland",
               "NST",
               "eur hañv Newfoundland",
               "NDT",
               "eur Newfoundland",
               "NT",
            };
        final String[] Turkmenistan = new String[] {
               "eur cʼhoañv Turkmenistan",
               "",
               "eur hañv Turkmenistan",
               "",
               "eur Turkmenistan",
               "",
            };
        final String[] French_Guiana = new String[] {
               "eur Gwiana cʼhall",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] New_Caledonia = new String[] {
               "eur cʼhoañv Kaledonia-Nevez",
               "",
               "eur hañv Kaledonia-Nevez",
               "",
               "eur Kaledonia-Nevez",
               "",
            };
        final String[] South_Georgia = new String[] {
               "eur Georgia ar Su",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Yekaterinburg = new String[] {
               "eur cʼhoañv Yekaterinbourg",
               "",
               "eur hañv Yekaterinbourg",
               "",
               "eur Yekaterinbourg",
               "",
            };
        final String[] Africa_Central = new String[] {
               "eur Kreizafrika",
               "CAT",
               "",
               "CAT",
               "",
               "CAT",
            };
        final String[] Africa_Eastern = new String[] {
               "eur Afrika ar Reter",
               "EAT",
               "",
               "EAT",
               "",
               "EAT",
            };
        final String[] Africa_Western = new String[] {
               "eur Afrika ar Cʼhornôg",
               "WAT",
               "",
               "WAT",
               "",
               "WAT",
            };
        final String[] DumontDUrville = new String[] {
               "eur Dumont-d’Urville",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Europe_Central = new String[] {
               "eur cʼhoañv Kreizeuropa",
               "CET",
               "eur hañv Kreizeuropa",
               "CEST",
               "eur Kreizeuropa",
               "CET",
            };
        final String[] Europe_Eastern = new String[] {
               "eur cʼhoañv Europa ar Reter",
               "EET",
               "eur hañv Europa ar Reter",
               "EEST",
               "eur Europa ar Reter",
               "EET",
            };
        final String[] Europe_Western = new String[] {
               "eur cʼhoañv Europa ar Cʼhornôg",
               "WET",
               "eur hañv Europa ar Cʼhornôg",
               "WEST",
               "eur Europa ar Cʼhornôg",
               "WET",
            };
        final String[] Mexico_Pacific = new String[] {
               "eur cʼhoañv an Habask mecʼhikan",
               "MST",
               "eur hañv an Habask mecʼhikan",
               "MDT",
               "eur an Habask mecʼhikan",
               "MT",
            };
        final String[] Africa_Southern = new String[] {
               "eur cʼhoañv Suafrika",
               "SAST",
               "",
               "SAST",
               "",
               "SAST",
            };
        final String[] America_Central = new String[] {
               "eur cʼhoañv ar Cʼhreiz",
               "CST",
               "eur hañv ar Cʼhreiz",
               "CDT",
               "eur ar Cʼhreiz",
               "CT",
            };
        final String[] America_Eastern = new String[] {
               "eur cʼhoañv ar Reter",
               "EST",
               "eur hañv ar Reter",
               "EST",
               "eur ar Reter",
               "EST",
            };
        final String[] America_Pacific = new String[] {
               "eur cʼhoañv an Habask",
               "PST",
               "eur hañv an Habask",
               "PDT",
               "eur an Habask",
               "PT",
            };
        final String[] French_Southern = new String[] {
               "eur Douaroù aostral Frañs hag Antarktika",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Gilbert_Islands = new String[] {
               "eur Inizi Gilbert",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Hawaii_Aleutian = new String[] {
               "eur cʼhoañv Hawaii hag an Aleouted",
               "HST",
               "eur hañv Hawaii hag an Aleouted",
               "HDT",
               "eur Hawaii hag an Aleouted",
               "HT",
            };
        final String[] Phoenix_Islands = new String[] {
               "eur Inizi Phoenix",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Pierre_Miquelon = new String[] {
               "eur cʼhoañv Sant-Pêr-ha-Mikelon",
               "",
               "eur hañv Sant-Pêr-ha-Mikelon",
               "",
               "eur Sant-Pêr-ha-Mikelon",
               "",
            };
        final String[] America_Mountain = new String[] {
               "eur cʼhoañv ar Menezioù",
               "MST",
               "eur hañv ar Menezioù",
               "MST",
               "eur ar Menezioù",
               "MST",
            };
        final String[] Marshall_Islands = new String[] {
               "eur Inizi Marshall",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Papua_New_Guinea = new String[] {
               "eur Papoua Ginea-Nevez",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Australia_Central = new String[] {
               "eur cʼhoañv Kreizaostralia",
               "ACST",
               "eur hañv Kreizaostralia",
               "ACDT",
               "eur Kreizaostralia",
               "ACT",
            };
        final String[] Australia_Eastern = new String[] {
               "eur cʼhoañv Aostralia ar Reter",
               "AEST",
               "eur hañv Aostralia ar Reter",
               "AEDT",
               "eur Aostralia ar Reter",
               "AET",
            };
        final String[] Australia_Western = new String[] {
               "eur cʼhoañv Aostralia ar Cʼhornôg",
               "AWST",
               "eur hañv Aostralia ar Cʼhornôg",
               "AWDT",
               "eur Aostralia ar Cʼhornôg",
               "AWT",
            };
        final String[] Indonesia_Central = new String[] {
               "eur Kreiz Indonezia",
               "WITA",
               "",
               "WITA",
               "",
               "WITA",
            };
        final String[] Indonesia_Eastern = new String[] {
               "eur Indonezia ar Reter",
               "WIT",
               "",
               "WIT",
               "",
               "WIT",
            };
        final String[] Indonesia_Western = new String[] {
               "eur Indonezia ar Cʼhornôg",
               "WIB",
               "",
               "WIB",
               "",
               "WIB",
            };
        final String[] Australia_CentralWestern = new String[] {
               "eur cʼhoañv Kreizaostralia ar Cʼhornôg",
               "",
               "eur hañv Kreizaostralia ar Cʼhornôg",
               "",
               "eur Kreizaostralia ar Cʼhornôg",
               "",
            };
        final Object[][] data = new Object[][] {
            { "America/Los_Angeles", America_Pacific },
            { "America/Denver", America_Mountain },
            { "America/Phoenix", America_Mountain },
            { "America/Chicago", America_Central },
            { "America/New_York", America_Eastern },
            { "America/Indianapolis", America_Eastern },
            { "Pacific/Honolulu", Hawaii },
            { "America/Anchorage", Alaska },
            { "America/Halifax", Atlantic },
            { "America/Sitka", Alaska },
            { "America/St_Johns", Newfoundland },
            { "Europe/Paris", Europe_Central },
            { "GMT", GMT },
            { "Asia/Jerusalem", Israel },
            { "Asia/Tokyo", Japan },
            { "Europe/Bucharest", Europe_Eastern },
            { "Asia/Shanghai", China },
            { "UTC", ETC_UTC },
            { "GB",
                new String[] {
                    "amzer keitat Greenwich (AKG)",
                    "GMT",
                    "eur hañv Breizh-Veur",
                    "BST",
                    "",
                    "GMT",
                }
            },
            { "NZ", New_Zealand },
            { "ACT", Australia_Central },
            { "AET", Australia_Eastern },
            { "AGT", Argentina },
            { "ART", Europe_Eastern },
            { "AST", Alaska },
            { "BET", Brasilia },
            { "BST", Bangladesh },
            { "CAT", Africa_Central },
            { "CET", Europe_Central },
            { "CNT", Newfoundland },
            { "CST", America_Central },
            { "CTT", China },
            { "EAT", Africa_Eastern },
            { "ECT", Europe_Central },
            { "EET", Europe_Eastern },
            { "EST", America_Eastern },
            { "HST", Hawaii },
            { "IET", America_Eastern },
            { "IST", India },
            { "JST", Japan },
            { "MET", Europe_Central },
            { "MIT", Apia },
            { "MST", America_Mountain },
            { "NET", Armenia },
            { "NST", New_Zealand },
            { "PLT", Pakistan },
            { "PNT", America_Mountain },
            { "PRC", China },
            { "PRT", Atlantic },
            { "PST", America_Pacific },
            { "ROK", Korea },
            { "SST", Solomon },
            { "UCT",
                new String[] {
                    "amzer hollvedel kenurzhiet",
                    "UTC",
                    "",
                    "UTC",
                    "",
                    "UTC",
                }
            },
            { "VST", Indochina },
            { "WET", Europe_Western },
            { "Cuba", Cuba },
            { "Eire",
                new String[] {
                    "amzer keitat Greenwich (AKG)",
                    "GMT",
                    "eur cʼhoañv Iwerzhon",
                    "IST",
                    "",
                    "GMT",
                }
            },
            { "GMT0", GMT },
            { "Iran", Iran },
            { "W-SU", Moscow },
            { "Zulu",
                new String[] {
                    "amzer hollvedel kenurzhiet",
                    "UTC",
                    "",
                    "UTC",
                    "",
                    "UTC",
                }
            },
            { "Egypt", Europe_Eastern },
            { "Japan", Japan },
            { "Libya", Europe_Eastern },
            { "Israel", Israel },
            { "Navajo", America_Mountain },
            { "Poland", Europe_Central },
            { "CST6CDT", America_Central },
            { "EST5EDT", America_Eastern },
            { "Etc/GMT", GMT },
            { "Etc/UCT",
                new String[] {
                    "amzer hollvedel kenurzhiet",
                    "UTC",
                    "",
                    "UTC",
                    "",
                    "UTC",
                }
            },
            { "Etc/UTC", ETC_UTC },
            { "GB-Eire",
                new String[] {
                    "amzer keitat Greenwich (AKG)",
                    "GMT",
                    "eur hañv Breizh-Veur",
                    "BST",
                    "",
                    "GMT",
                }
            },
            { "Iceland", GMT },
            { "Jamaica", America_Eastern },
            { "MST7MDT", America_Mountain },
            { "NZ-CHAT", Chatham },
            { "PST8PDT", America_Pacific },
            { "Etc/GMT0", GMT },
            { "Etc/Zulu",
                new String[] {
                    "amzer hollvedel kenurzhiet",
                    "UTC",
                    "",
                    "UTC",
                    "",
                    "UTC",
                }
            },
            { "Hongkong", Hong_Kong },
            { "Portugal", Europe_Western },
            { "US/Samoa", Samoa },
            { "Asia/Aden", Arabian },
            { "Asia/Baku", Azerbaijan },
            { "Asia/Dili", East_Timor },
            { "Asia/Gaza", Europe_Eastern },
            { "Asia/Hovd", Hovd },
            { "Asia/Omsk", Omsk },
            { "Asia/Oral", Kazakhstan },
            { "Etc/GMT+0", GMT },
            { "Etc/GMT-0", GMT },
            { "Greenwich", GMT },
            { "Kwajalein", Marshall_Islands },
            { "Singapore", Singapore },
            { "US/Alaska", Alaska },
            { "US/Hawaii", Hawaii },
            { "Universal",
                new String[] {
                    "amzer hollvedel kenurzhiet",
                    "UTC",
                    "",
                    "UTC",
                    "",
                    "UTC",
                }
            },
            { "Asia/Aqtau", Kazakhstan },
            { "Asia/Chita", Yakutsk },
            { "Asia/Dacca", Bangladesh },
            { "Asia/Dhaka", Bangladesh },
            { "Asia/Dubai", Gulf },
            { "Asia/Kabul", Afghanistan },
            { "Asia/Macao", China },
            { "Asia/Macau", China },
            { "Asia/Qatar", Arabian },
            { "Asia/Seoul", Korea },
            { "Asia/Tomsk", Krasnoyarsk },
            { "US/Arizona", America_Mountain },
            { "US/Central", America_Central },
            { "US/Eastern", America_Eastern },
            { "US/Pacific", America_Pacific },
            { "Africa/Juba", Africa_Central },
            { "Africa/Lome", GMT },
            { "Asia/Almaty", Kazakhstan },
            { "Asia/Aqtobe", Kazakhstan },
            { "Asia/Atyrau", Kazakhstan },
            { "Asia/Beirut", Europe_Eastern },
            { "Asia/Brunei", Brunei },
            { "Asia/Harbin", China },
            { "Asia/Hebron", Europe_Eastern },
            { "Asia/Kuwait", Arabian },
            { "Asia/Manila", Philippines },
            { "Asia/Muscat", Gulf },
            { "Asia/Riyadh", Arabian },
            { "Asia/Saigon", Indochina },
            { "Asia/Taipei", Taipei },
            { "Asia/Tehran", Iran },
            { "Asia/Thimbu", Bhutan },
            { "Asia/Yangon", Cocos },
            { "Brazil/East", Brasilia },
            { "Brazil/West", Amazon },
            { "Europe/Kiev", Europe_Eastern },
            { "Europe/Kyiv", Europe_Eastern },
            { "Europe/Oslo", Europe_Central },
            { "Europe/Riga", Europe_Eastern },
            { "Europe/Rome", Europe_Central },
            { "Indian/Mahe", Seychelles },
            { "Pacific/Yap", Papua_New_Guinea },
            { "US/Aleutian", Hawaii_Aleutian },
            { "US/Michigan", America_Eastern },
            { "US/Mountain", America_Mountain },
            { "Africa/Accra", GMT },
            { "Africa/Cairo", Europe_Eastern },
            { "Africa/Ceuta", Europe_Central },
            { "Africa/Dakar", GMT },
            { "Africa/Lagos", Africa_Western },
            { "Africa/Tunis", Europe_Central },
            { "America/Adak", Hawaii_Aleutian },
            { "America/Atka", Hawaii_Aleutian },
            { "America/Lima", Peru },
            { "America/Nome", Alaska },
            { "Asia/Baghdad", Arabian },
            { "Asia/Bahrain", Arabian },
            { "Asia/Bangkok", Indochina },
            { "Asia/Barnaul", Krasnoyarsk },
            { "Asia/Bishkek", Kyrgystan },
            { "Asia/Colombo", India },
            { "Asia/Irkutsk", Irkutsk },
            { "Asia/Jakarta", Indonesia_Western },
            { "Asia/Karachi", Pakistan },
            { "Asia/Kolkata", India },
            { "Asia/Kuching", Brunei },
            { "Asia/Magadan", Magadan },
            { "Asia/Nicosia", Europe_Eastern },
            { "Asia/Rangoon", Myanmar },
            { "Asia/Tbilisi", Georgia },
            { "Asia/Thimphu", Bhutan },
            { "Asia/Yakutsk", Yakutsk },
            { "Asia/Yerevan", Armenia },
            { "Canada/Yukon", Yukon },
            { "Europe/Kirov", Moscow },
            { "Europe/Malta", Europe_Central },
            { "Europe/Minsk", Moscow },
            { "Europe/Sofia", Europe_Eastern },
            { "Europe/Vaduz", Europe_Central },
            { "Indian/Cocos", Cocos },
            { "Pacific/Apia", Apia },
            { "Pacific/Fiji", Fiji },
            { "Pacific/Guam", Chamorro },
            { "Pacific/Niue", Niue },
            { "Pacific/Truk", Truk },
            { "Pacific/Wake", Wake },
            { "SystemV/AST4", Atlantic },
            { "SystemV/CST6", America_Central },
            { "SystemV/EST5", America_Eastern },
            { "SystemV/MST7", America_Mountain },
            { "SystemV/PST8", Pitcairn },
            { "SystemV/YST9", Gambier },
            { "Africa/Asmara", Africa_Eastern },
            { "Africa/Asmera", Africa_Eastern },
            { "Africa/Bamako", GMT },
            { "Africa/Bangui", Africa_Western },
            { "Africa/Banjul", GMT },
            { "Africa/Bissau", GMT },
            { "Africa/Douala", Africa_Western },
            { "Africa/Harare", Africa_Central },
            { "Africa/Kigali", Africa_Central },
            { "Africa/Luanda", Africa_Western },
            { "Africa/Lusaka", Africa_Central },
            { "Africa/Malabo", Africa_Western },
            { "Africa/Maputo", Africa_Central },
            { "Africa/Maseru", Africa_Southern },
            { "Africa/Niamey", Africa_Western },
            { "America/Aruba", Atlantic },
            { "America/Bahia", Brasilia },
            { "America/Belem", Brasilia },
            { "America/Boise", America_Mountain },
            { "America/Jujuy", Argentina },
            { "America/Thule", Atlantic },
            { "Asia/Ashgabat", Turkmenistan },
            { "Asia/Calcutta", India },
            { "Asia/Dushanbe", Tajikistan },
            { "Asia/Jayapura", Indonesia_Eastern },
            { "Asia/Katmandu", Nepal },
            { "Asia/Khandyga", Yakutsk },
            { "Asia/Makassar", Indonesia_Central },
            { "Asia/Qostanay", Kazakhstan },
            { "Asia/Sakhalin", Magadan },
            { "Asia/Tashkent", Uzbekistan },
            { "Asia/Tel_Aviv", Israel },
            { "Asia/Ust-Nera", Vladivostok },
            { "Australia/ACT", Australia_Eastern },
            { "Australia/LHI", Lord_Howe },
            { "Australia/NSW", Australia_Eastern },
            { "Etc/Greenwich", GMT },
            { "Etc/Universal",
                new String[] {
                    "amzer hollvedel kenurzhiet",
                    "UTC",
                    "",
                    "UTC",
                    "",
                    "UTC",
                }
            },
            { "Europe/Athens", Europe_Eastern },
            { "Europe/Berlin", Europe_Central },
            { "Europe/Dublin",
                new String[] {
                    "amzer keitat Greenwich (AKG)",
                    "GMT",
                    "eur cʼhoañv Iwerzhon",
                    "IST",
                    "",
                    "GMT",
                }
            },
            { "Europe/Jersey",
                new String[] {
                    "amzer keitat Greenwich (AKG)",
                    "GMT",
                    "eur hañv Breizh-Veur",
                    "BST",
                    "",
                    "GMT",
                }
            },
            { "Europe/Lisbon", Europe_Western },
            { "Europe/London",
                new String[] {
                    "amzer keitat Greenwich (AKG)",
                    "GMT",
                    "eur hañv Breizh-Veur",
                    "BST",
                    "",
                    "GMT",
                }
            },
            { "Europe/Madrid", Europe_Central },
            { "Europe/Monaco", Europe_Central },
            { "Europe/Moscow", Moscow },
            { "Europe/Prague", Europe_Central },
            { "Europe/Skopje", Europe_Central },
            { "Europe/Tirane", Europe_Central },
            { "Europe/Vienna", Europe_Central },
            { "Europe/Warsaw", Europe_Central },
            { "Europe/Zagreb", Europe_Central },
            { "Europe/Zurich", Europe_Central },
            { "Indian/Chagos", Indian_Ocean },
            { "Indian/Comoro", Africa_Eastern },
            { "Pacific/Chuuk", Papua_New_Guinea },
            { "Pacific/Efate", Vanuatu },
            { "Pacific/Nauru", Nauru },
            { "Pacific/Palau", Palau },
            { "Pacific/Samoa", Samoa },
            { "SystemV/HST10", Hawaii },
            { "Africa/Abidjan", GMT },
            { "Africa/Algiers", Europe_Central },
            { "Africa/Conakry", GMT },
            { "Africa/Kampala", Africa_Eastern },
            { "Africa/Mbabane", Africa_Southern },
            { "Africa/Nairobi", Africa_Eastern },
            { "Africa/Tripoli", Europe_Eastern },
            { "America/Belize", America_Central },
            { "America/Bogota", Colombia },
            { "America/Cancun", America_Eastern },
            { "America/Cayman", America_Eastern },
            { "America/Cuiaba", Amazon },
            { "America/Dawson", Yukon },
            { "America/Guyana", Guyana },
            { "America/Havana", Cuba },
            { "America/Inuvik", America_Mountain },
            { "America/Juneau", Alaska },
            { "America/La_Paz", Bolivia },
            { "America/Maceio", Brasilia },
            { "America/Manaus", Amazon },
            { "America/Merida", America_Central },
            { "America/Nassau", America_Eastern },
            { "America/Panama", America_Eastern },
            { "America/Recife", Brasilia },
            { "America/Regina", America_Central },
            { "America/Virgin", Atlantic },
            { "Asia/Ashkhabad", Turkmenistan },
            { "Asia/Chongqing", China },
            { "Asia/Chungking", China },
            { "Asia/Famagusta", Europe_Eastern },
            { "Asia/Hong_Kong", Hong_Kong },
            { "Asia/Kathmandu", Nepal },
            { "Asia/Pontianak", Indonesia_Western },
            { "Asia/Pyongyang", Korea },
            { "Asia/Qyzylorda", Kazakhstan },
            { "Asia/Samarkand", Uzbekistan },
            { "Asia/Singapore", Singapore },
            { "Asia/Vientiane", Indochina },
            { "Atlantic/Faroe", Europe_Western },
            { "Australia/West", Australia_Western },
            { "Canada/Central", America_Central },
            { "Canada/Eastern", America_Eastern },
            { "Canada/Pacific", America_Pacific },
            { "Europe/Andorra", Europe_Central },
            { "Europe/Belfast",
                new String[] {
                    "amzer keitat Greenwich (AKG)",
                    "GMT",
                    "eur hañv Breizh-Veur",
                    "BST",
                    "",
                    "GMT",
                }
            },
            { "Europe/Nicosia", Europe_Eastern },
            { "Europe/Tallinn", Europe_Eastern },
            { "Europe/Vatican", Europe_Central },
            { "Europe/Vilnius", Europe_Eastern },
            { "Indian/Mayotte", Africa_Eastern },
            { "Indian/Reunion", Reunion },
            { "Mexico/BajaSur", Mexico_Pacific },
            { "Mexico/General", America_Central },
            { "Pacific/Easter", Easter },
            { "Pacific/Kanton", Phoenix_Islands },
            { "Pacific/Kosrae", Kosrae },
            { "Pacific/Majuro", Marshall_Islands },
            { "Pacific/Midway", Samoa },
            { "Pacific/Noumea", New_Caledonia },
            { "Pacific/Ponape", Solomon },
            { "Pacific/Saipan", Chamorro },
            { "Pacific/Tahiti", Tahiti },
            { "Pacific/Tarawa", Marshall_Islands },
            { "Pacific/Wallis", Gilbert_Islands },
            { "Africa/Blantyre", Africa_Central },
            { "Africa/Djibouti", Africa_Eastern },
            { "Africa/Freetown", GMT },
            { "Africa/Gaborone", Africa_Central },
            { "Africa/Khartoum", Africa_Central },
            { "Africa/Kinshasa", Africa_Western },
            { "Africa/Monrovia", GMT },
            { "Africa/Ndjamena", Africa_Western },
            { "Africa/Sao_Tome", GMT },
            { "Africa/Timbuktu", GMT },
            { "Africa/Windhoek", Africa_Central },
            { "America/Antigua", Atlantic },
            { "America/Caracas", Venezuela },
            { "America/Cayenne", French_Guiana },
            { "America/Cordoba", Argentina },
            { "America/Creston", America_Mountain },
            { "America/Curacao", Atlantic },
            { "America/Detroit", America_Eastern },
            { "America/Grenada", Atlantic },
            { "America/Iqaluit", America_Eastern },
            { "America/Jamaica", America_Eastern },
            { "America/Knox_IN", America_Central },
            { "America/Managua", America_Central },
            { "America/Marigot", Atlantic },
            { "America/Mendoza", Argentina },
            { "America/Moncton", Atlantic },
            { "America/Nipigon", America_Eastern },
            { "America/Noronha", Noronha },
            { "America/Ojinaga", America_Central },
            { "America/Tijuana", America_Pacific },
            { "America/Toronto", America_Eastern },
            { "America/Tortola", Atlantic },
            { "America/Yakutat", Alaska },
            { "Asia/Choibalsan", Mongolia },
            { "Asia/Phnom_Penh", Indochina },
            { "Asia/Ulan_Bator", Mongolia },
            { "Atlantic/Azores", Azores },
            { "Atlantic/Canary", Europe_Western },
            { "Atlantic/Faeroe", Europe_Western },
            { "Australia/Eucla", Australia_CentralWestern },
            { "Australia/North", Australia_Central },
            { "Australia/Perth", Australia_Western },
            { "Australia/South", Australia_Central },
            { "Canada/Atlantic", Atlantic },
            { "Canada/Mountain", America_Mountain },
            { "Europe/Belgrade", Europe_Central },
            { "Europe/Brussels", Europe_Central },
            { "Europe/Budapest", Europe_Central },
            { "Europe/Busingen", Europe_Central },
            { "Europe/Chisinau", Europe_Eastern },
            { "Europe/Guernsey",
                new String[] {
                    "amzer keitat Greenwich (AKG)",
                    "GMT",
                    "eur hañv Breizh-Veur",
                    "BST",
                    "",
                    "GMT",
                }
            },
            { "Europe/Helsinki", Europe_Eastern },
            { "Europe/Sarajevo", Europe_Central },
            { "Europe/Tiraspol", Europe_Eastern },
            { "Europe/Uzhgorod", Europe_Eastern },
            { "Indian/Maldives", French_Southern },
            { "Pacific/Chatham", Chatham },
            { "Pacific/Fakaofo", Tokelau },
            { "Pacific/Gambier", Gambier },
            { "Pacific/Norfolk", Norfolk },
            { "Pacific/Pohnpei", Solomon },
            { "SystemV/AST4ADT", Atlantic },
            { "SystemV/CST6CDT", America_Central },
            { "SystemV/EST5EDT", America_Eastern },
            { "SystemV/MST7MDT", America_Mountain },
            { "SystemV/PST8PDT", America_Pacific },
            { "SystemV/YST9YDT", Alaska },
            { "Africa/Bujumbura", Africa_Central },
            { "Africa/Mogadishu", Africa_Eastern },
            { "America/Anguilla", Atlantic },
            { "America/Asuncion", Paraguay },
            { "America/Atikokan", America_Eastern },
            { "America/Barbados", Atlantic },
            { "America/Dominica", Atlantic },
            { "America/Edmonton", America_Mountain },
            { "America/Ensenada", America_Pacific },
            { "America/Mazatlan", Mexico_Pacific },
            { "America/Miquelon", Pierre_Miquelon },
            { "America/Montreal", America_Eastern },
            { "America/Resolute", America_Central },
            { "America/Santarem", Brasilia },
            { "America/Santiago", Chile },
            { "America/Shiprock", America_Mountain },
            { "America/St_Kitts", Atlantic },
            { "America/St_Lucia", Atlantic },
            { "America/Winnipeg", America_Central },
            { "Antarctica/Casey", Australia_Western },
            { "Antarctica/Davis", Davis },
            { "Antarctica/Syowa", Syowa },
            { "Antarctica/Troll", GMT },
            { "Asia/Ho_Chi_Minh", Indochina },
            { "Asia/Krasnoyarsk", Krasnoyarsk },
            { "Asia/Novosibirsk", Krasnoyarsk },
            { "Asia/Ulaanbaatar", Mongolia },
            { "Asia/Vladivostok", Vladivostok },
            { "Atlantic/Bermuda", Atlantic },
            { "Atlantic/Madeira", Europe_Western },
            { "Atlantic/Stanley", Falkland },
            { "Australia/Currie", Australia_Eastern },
            { "Australia/Darwin", Australia_Central },
            { "Australia/Hobart", Australia_Eastern },
            { "Australia/Sydney", Australia_Eastern },
            { "Brazil/DeNoronha", Noronha },
            { "Europe/Amsterdam", Europe_Central },
            { "Europe/Gibraltar", Europe_Central },
            { "Europe/Ljubljana", Europe_Central },
            { "Europe/Mariehamn", Europe_Eastern },
            { "Europe/Podgorica", Europe_Central },
            { "Europe/Stockholm", Europe_Central },
            { "Europe/Volgograd", Moscow },
            { "Indian/Christmas", Christmas },
            { "Indian/Kerguelen", French_Southern },
            { "Indian/Mauritius", Mauritius },
            { "Mexico/BajaNorte", America_Pacific },
            { "Pacific/Auckland", New_Zealand },
            { "Pacific/Funafuti", Tuvalu },
            { "Pacific/Johnston", Hawaii },
            { "Pacific/Pitcairn", Pitcairn },
            { "Africa/Libreville", Africa_Western },
            { "Africa/Lubumbashi", Africa_Central },
            { "Africa/Nouakchott", GMT },
            { "Africa/Porto-Novo", Africa_Western },
            { "America/Araguaina", Brasilia },
            { "America/Boa_Vista", Amazon },
            { "America/Catamarca", Argentina },
            { "America/Chihuahua", America_Central },
            { "America/Fortaleza", Brasilia },
            { "America/Glace_Bay", Atlantic },
            { "America/Goose_Bay", Atlantic },
            { "America/Guatemala", America_Central },
            { "America/Guayaquil", Ecuador },
            { "America/Matamoros", America_Central },
            { "America/Menominee", America_Central },
            { "America/Monterrey", America_Central },
            { "America/Sao_Paulo", Brasilia },
            { "America/St_Thomas", Atlantic },
            { "America/Vancouver", America_Pacific },
            { "Antarctica/Mawson", Mawson },
            { "Antarctica/Vostok", Vostok },
            { "Asia/Kuala_Lumpur", Malaysia },
            { "Asia/Novokuznetsk", Krasnoyarsk },
            { "Chile/Continental", Chile },
            { "Europe/Bratislava", Europe_Central },
            { "Europe/Copenhagen", Europe_Central },
            { "Europe/Luxembourg", Europe_Central },
            { "Europe/San_Marino", Europe_Central },
            { "Europe/Simferopol", Moscow },
            { "Europe/Zaporozhye", Europe_Eastern },
            { "Pacific/Enderbury", Phoenix_Islands },
            { "Pacific/Galapagos", Galapagos },
            { "Pacific/Kwajalein", Marshall_Islands },
            { "Pacific/Marquesas", Marquesas },
            { "Pacific/Pago_Pago", Samoa },
            { "Pacific/Rarotonga", Cook },
            { "Pacific/Tongatapu", Tonga },
            { "US/Indiana-Starke", America_Central },
            { "Africa/Addis_Ababa", Africa_Eastern },
            { "Africa/Brazzaville", Africa_Western },
            { "Africa/Ouagadougou", GMT },
            { "America/Costa_Rica", America_Central },
            { "America/Grand_Turk", America_Eastern },
            { "America/Guadeloupe", Atlantic },
            { "America/Hermosillo", Mexico_Pacific },
            { "America/Kralendijk", Atlantic },
            { "America/Louisville", America_Eastern },
            { "America/Martinique", Atlantic },
            { "America/Metlakatla", Alaska },
            { "America/Montevideo", Uruguay },
            { "America/Montserrat", Atlantic },
            { "America/Paramaribo", Suriname },
            { "America/St_Vincent", Atlantic },
            { "America/Whitehorse", Yukon },
            { "Antarctica/McMurdo", New_Zealand },
            { "Antarctica/Rothera", Rothera },
            { "Asia/Srednekolymsk", Magadan },
            { "Asia/Ujung_Pandang", Indonesia_Central },
            { "Asia/Yekaterinburg", Yekaterinburg },
            { "Atlantic/Jan_Mayen", Europe_Central },
            { "Atlantic/Reykjavik", GMT },
            { "Atlantic/St_Helena", GMT },
            { "Australia/Adelaide", Australia_Central },
            { "Australia/Brisbane", Australia_Eastern },
            { "Australia/Canberra", Australia_Eastern },
            { "Australia/Lindeman", Australia_Eastern },
            { "Australia/Tasmania", Australia_Eastern },
            { "Australia/Victoria", Australia_Eastern },
            { "Chile/EasterIsland", Easter },
            { "Europe/Isle_of_Man",
                new String[] {
                    "amzer keitat Greenwich (AKG)",
                    "GMT",
                    "eur hañv Breizh-Veur",
                    "BST",
                    "",
                    "GMT",
                }
            },
            { "Europe/Kaliningrad", Europe_Eastern },
            { "Pacific/Kiritimati", Line_Islands },
            { "Africa/Johannesburg", Africa_Southern },
            { "America/El_Salvador", America_Central },
            { "America/Fort_Nelson", America_Mountain },
            { "America/Mexico_City", America_Central },
            { "America/Pangnirtung", America_Eastern },
            { "America/Porto_Velho", Amazon },
            { "America/Puerto_Rico", Atlantic },
            { "America/Rainy_River", America_Central },
            { "America/Tegucigalpa", America_Central },
            { "America/Thunder_Bay", America_Eastern },
            { "America/Yellowknife", America_Mountain },
            { "Arctic/Longyearbyen", Europe_Central },
            { "Atlantic/Cape_Verde", Cape_Verde },
            { "Australia/Lord_Howe", Lord_Howe },
            { "Australia/Melbourne", Australia_Eastern },
            { "Canada/Newfoundland", Newfoundland },
            { "Canada/Saskatchewan", America_Central },
            { "Indian/Antananarivo", Africa_Eastern },
            { "Pacific/Guadalcanal", Solomon },
            { "Africa/Dar_es_Salaam", Africa_Eastern },
            { "America/Blanc-Sablon", Atlantic },
            { "America/Buenos_Aires", Argentina },
            { "America/Campo_Grande", Amazon },
            { "America/Danmarkshavn", GMT },
            { "America/Dawson_Creek", America_Mountain },
            { "America/Indiana/Knox", America_Central },
            { "America/Rankin_Inlet", America_Central },
            { "America/Santa_Isabel", America_Pacific },
            { "Antarctica/Macquarie", Australia_Eastern },
            { "Australia/Queensland", Australia_Eastern },
            { "Australia/Yancowinna", Australia_Central },
            { "Pacific/Port_Moresby", DumontDUrville },
            { "America/Cambridge_Bay", America_Mountain },
            { "America/Ciudad_Juarez", America_Mountain },
            { "America/Coral_Harbour", America_Eastern },
            { "America/Indiana/Vevay", America_Eastern },
            { "America/Lower_Princes", Atlantic },
            { "America/Port_of_Spain", Atlantic },
            { "America/Santo_Domingo", Atlantic },
            { "America/St_Barthelemy", Atlantic },
            { "America/Swift_Current", America_Central },
            { "Antarctica/South_Pole", New_Zealand },
            { "Australia/Broken_Hill", Australia_Central },
            { "America/Bahia_Banderas", America_Central },
            { "America/Port-au-Prince", America_Eastern },
            { "Atlantic/South_Georgia", South_Georgia },
            { "America/Argentina/Jujuy", Argentina },
            { "America/Argentina/Salta", Argentina },
            { "America/Indiana/Marengo", America_Eastern },
            { "America/Indiana/Winamac", America_Eastern },
            { "America/Argentina/Cordoba", Argentina },
            { "America/Argentina/Mendoza", Argentina },
            { "America/Argentina/Tucuman", Argentina },
            { "America/Argentina/Ushuaia", Argentina },
            { "America/Indiana/Tell_City", America_Central },
            { "America/Indiana/Vincennes", America_Eastern },
            { "Antarctica/DumontDUrville", DumontDUrville },
            { "timezone.excity.Asia/Baku", "Bakou" },
            { "America/Argentina/La_Rioja", Argentina },
            { "America/Argentina/San_Juan", Argentina },
            { "America/Argentina/San_Luis", Argentina },
            { "America/Indiana/Petersburg", America_Eastern },
            { "timezone.excity.Asia/Chita", "Tchita" },
            { "timezone.excity.Asia/Kabul", "Kaboul" },
            { "timezone.excity.Asia/Macau", "Makao" },
            { "America/Argentina/Catamarca", Argentina },
            { "America/Kentucky/Louisville", America_Eastern },
            { "America/Kentucky/Monticello", America_Eastern },
            { "America/North_Dakota/Beulah", America_Central },
            { "America/North_Dakota/Center", America_Central },
            { "timezone.excity.Asia/Anadyr", "Anadyrʼ" },
            { "timezone.excity.Asia/Beirut", "Bayrut" },
            { "timezone.excity.Asia/Kuwait", "Koweit" },
            { "timezone.excity.Asia/Muscat", "Masqat" },
            { "timezone.excity.Asia/Saigon", "Kêr Hô-Chi-Minh" },
            { "timezone.excity.Etc/Unknown", "Lecʼhiadur dianav" },
            { "timezone.excity.Europe/Kiev", "Kyyiv" },
            { "timezone.excity.Europe/Rome", "Roma" },
            { "America/Indiana/Indianapolis", America_Eastern },
            { "timezone.excity.Africa/Cairo", "Kaero" },
            { "timezone.excity.Africa/Tunis", "Tuniz" },
            { "timezone.excity.Asia/Bahrain", "Bahrein" },
            { "timezone.excity.Asia/Colombo", "Kolamba" },
            { "timezone.excity.Asia/Nicosia", "Levkosía" },
            { "timezone.excity.Europe/Minsk", "Mensk" },
            { "timezone.excity.Europe/Paris", "Pariz" },
            { "timezone.excity.Indian/Cocos", "Kokoz" },
            { "timezone.excity.Pacific/Fiji", "Fidji" },
            { "timezone.excity.Pacific/Wake", "Enez Wake" },
            { "timezone.excity.America/Thule", "Qaanaaq" },
            { "timezone.excity.Asia/Damascus", "Damask" },
            { "timezone.excity.Asia/Tashkent", "Toshkent" },
            { "timezone.excity.Europe/Athens", "Aten" },
            { "timezone.excity.Europe/Dublin", "Dulenn" },
            { "timezone.excity.Europe/Jersey", "Jerzenez" },
            { "timezone.excity.Europe/Lisbon", "Lisboa" },
            { "timezone.excity.Europe/London", "Londrez" },
            { "timezone.excity.Europe/Moscow", "Moskov" },
            { "timezone.excity.Europe/Prague", "Praha" },
            { "timezone.excity.Europe/Tirane", "Tiranë" },
            { "timezone.excity.Europe/Warsaw", "Varsovia" },
            { "timezone.excity.Indian/Comoro", "Komorez" },
            { "America/Argentina/Buenos_Aires", Argentina },
            { "America/Argentina/Rio_Gallegos", Argentina },
            { "America/North_Dakota/New_Salem", America_Central },
            { "timezone.excity.Africa/Algiers", "Aljer" },
            { "timezone.excity.Africa/Tripoli", "Tarabulus (Tripoli)" },
            { "timezone.excity.America/Havana", "La Habana" },
            { "timezone.excity.America/Panama", "Panamá" },
            { "timezone.excity.Asia/Jerusalem", "Jeruzalem" },
            { "timezone.excity.Asia/Kamchatka", "Kamtchatka" },
            { "timezone.excity.Asia/Singapore", "Singapour" },
            { "timezone.excity.Asia/Vientiane", "Viangchan" },
            { "timezone.excity.Europe/Vatican", "Vatikan" },
            { "timezone.excity.Indian/Reunion", "Reünion" },
            { "timezone.excity.Pacific/Easter", "Enez Pask" },
            { "timezone.excity.Pacific/Midway", "Inizi Midway" },
            { "timezone.excity.Pacific/Noumea", "Noumea" },
            { "timezone.excity.Pacific/Wallis", "Wallis-ha-Futuna" },
            { "timezone.excity.Africa/El_Aaiun", "LaʼYoun" },
            { "timezone.excity.Africa/Ndjamena", "NʼDjamena" },
            { "timezone.excity.America/Godthab", "Nuuk (Godthåb)" },
            { "timezone.excity.America/Jamaica", "Jamaika" },
            { "timezone.excity.Asia/Phnom_Penh", "Phnum Pénh" },
            { "timezone.excity.Atlantic/Azores", "Azorez" },
            { "timezone.excity.Atlantic/Canary", "Kanariez" },
            { "timezone.excity.Atlantic/Faeroe", "Faero" },
            { "timezone.excity.Europe/Belgrade", "Beograd" },
            { "timezone.excity.Europe/Brussels", "Brusel" },
            { "timezone.excity.Europe/Guernsey", "Gwernenez" },
            { "timezone.excity.Indian/Maldives", "Maldivez" },
            { "timezone.excity.Africa/Mogadishu", "Muqdisho" },
            { "timezone.excity.America/Miquelon", "Mikelon" },
            { "timezone.excity.America/St_Johns", "Saint Johnʼs" },
            { "timezone.excity.America/St_Kitts", "Saint Kitts" },
            { "timezone.excity.America/St_Lucia", "Saint Lucia" },
            { "timezone.excity.Atlantic/Bermuda", "Bermudez" },
            { "timezone.excity.Europe/Bucharest", "Bukarest" },
            { "timezone.excity.Europe/Gibraltar", "Jibraltar" },
            { "timezone.excity.Europe/Mariehamn", "Marjehamn" },
            { "timezone.excity.Indian/Kerguelen", "Kergelenn" },
            { "timezone.excity.Indian/Mauritius", "Moris" },
            { "timezone.excity.Pacific/Honolulu", "Honolulu" },
            { "timezone.excity.Pacific/Pitcairn", "Inizi Pitcairn" },
            { "timezone.excity.Africa/Casablanca", "Dar el Beida (Casablanca)" },
            { "timezone.excity.Europe/Copenhagen", "Kopenhagen" },
            { "timezone.excity.Europe/Luxembourg", "Luksembourg" },
            { "timezone.excity.Pacific/Marquesas", "Inizi Markiz" },
            { "timezone.excity.Africa/Addis_Ababa", "Adis Abeba" },
            { "timezone.excity.America/Guadeloupe", "Gwadeloup" },
            { "timezone.excity.America/Martinique", "Martinik" },
            { "timezone.excity.America/St_Vincent", "Sant-Visant" },
            { "timezone.excity.Asia/Yekaterinburg", "Yekaterinbourg" },
            { "timezone.excity.Atlantic/Reykjavik", "Reykjavík" },
            { "timezone.excity.Atlantic/St_Helena", "Saint-Helena" },
            { "timezone.excity.Europe/Isle_of_Man", "Manav" },
            { "timezone.excity.America/El_Salvador", "Salvador" },
            { "timezone.excity.America/Mexico_City", "Kêr Vecʼhiko" },
            { "timezone.excity.Atlantic/Cape_Verde", "Kab-Glas" },
            { "timezone.excity.America/St_Barthelemy", "Sant-Bertele" },
            { "timezone.excity.Atlantic/South_Georgia", "Georgia ar Su" },
        };
        return data;
    }
}
